package com.ruoyi.system.service.impl;

import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.bean.BeanValidators;
import com.ruoyi.system.domain.PostUser;
import com.ruoyi.system.mapper.PostUserMapper;
import com.ruoyi.system.service.ILcdInfoImportDataService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.validation.Validator;
import java.util.List;

@Service
public class ILcdInfoImportDataImpl implements ILcdInfoImportDataService {
    @Autowired
    private PostUserMapper postUserMapper;
    @Autowired
    private static final Logger log = LoggerFactory.getLogger(SysUserServiceImpl.class);

    @Autowired
    protected Validator validator;

    @Override
    public String importData(List<PostUser> postUser, Boolean isUpdateSupport, String operName) {
        if (StringUtils.isNull(postUser) || postUser.size() == 0)
        {
            throw new ServiceException("导入学生基本信息数据不能为空！");
        }
        int successNum = 0;
        int failureNum = 0;
        StringBuilder successMsg = new StringBuilder();
        StringBuilder failureMsg = new StringBuilder();
        for (PostUser stu : postUser)
        {
            try
            {
                // 验证是否存在这个用户
                PostUser u = postUserMapper.selectPostUserByNumber(stu.getMobile());
                if (StringUtils.isNull(u))
                {
                    BeanValidators.validateWithException(validator, stu);
                    stu.setCreateBy(operName);
                    this.postUserMapper.insertPostUser(stu);
                    successNum++;
                    successMsg.append("<br/>" + successNum + "、手机 " + stu.getMobile() + " 导入成功");
                }
                else if (isUpdateSupport)
                {
                    BeanValidators.validateWithException(validator, stu);
                    stu.setUpdateBy(operName);
                    this.postUserMapper.updatePostUser(stu);
                    successNum++;
                    successMsg.append("<br/>" + successNum + "、手机 " + stu.getMobile() + " 更新成功");
                }
                else
                {
                    failureNum++;
                    failureMsg.append("<br/>" + failureNum + "、手机 " + stu.getMobile() + " 已存在");
                }
            }
            catch (Exception e)
            {
                failureNum++;
                String msg = "<br/>" + failureNum + "、手机 " + stu.getMobile() + " 导入失败：";
                failureMsg.append(msg + e.getMessage());
                log.error(msg, e);
            }
        }
        if (failureNum > 0)
        {
            failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据格式不正确，错误如下：");
            throw new ServiceException(failureMsg.toString());
        }
        else
        {
            successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
        }
        return successMsg.toString();
    }

}
